@@ -1,4 +1,4 @@
-char *version_string = "@(#)Gnu Awk (gawk) 2.10beta 07 Apr 1989\n" + 4;
+char *version_string = "@(#)Gnu Awk (gawk) 2.11";
 
 /* 1.02		fixed /= += *= etc to return the new Left Hand Side instead
 		of the Right Hand Side */
@@ -29,3 +29,6 @@ char *version_string = "@(#)Gnu Awk (gawk) 2.10beta 07 Apr 1989\n" + 4;
 		A number of minor bug fixes and new features from Arnold.
 		Changes for MSDOS from Conrad Kwok and Scott Garfinkle.
 		The gawk.texinfo and info files included! */
+
+/* 2.11		Bug fix release to 2.10.  Lots of changes for portability,
+		speed, and configurability.  */
